from enum import Enum



NCS2_VID = 0x03e7
NCS2_PID = 0x2485


CUDA_SUPPORTED_BOARDS = {'nano': '33', 'tx2': '24', 'xavier_nx': '25'}
  # {Board: ChipId, ..}
TEGRA_CHIP_PATH = "/sys/module/tegra_fuse/parameters/tegra_chip_id"

MYRIAD_SUPPORTED_OS = ['Linux']

EYECLOUD_SUPPORTED_MODEL_PURPOSES = ['ObjectDetection', 'Classification', 'PoseEstimation']


class Engine(Enum):
    """Software inference engines supported by edgeIQ"""

    DNN = 'DNN'
    """
    OpenCV's DNN backend.

    Supports:

    * :class:`Accelerator.GPU` (DEFAULT)
    * :class:`Accelerator.CPU`
    """

    DNN_OPENVINO = 'DNN_OPENVINO'
    """
    OpenCV's OpenVINO Inference Engine backend.

    Supports:

    * :class:`Accelerator.MYRIAD` (DEFAULT)
    """

    DNN_CUDA = 'DNN_CUDA'
    """
    OpenCV's CUDA Inference Engine backend.

    Supports:

    * :class:`Accelerator.NVIDIA` (DEFAULT)
    * :class:`Accelerator.NVIDIA_FP16`
    """

    TENSOR_RT = 'TENSOR_RT'
    """
    Tensor RT Engine

    Supports:

    * :class:`Accelerator.NVIDIA`
    """


class Accelerator(Enum):
    """HW accelerators supported by edgeIQ"""

    DEFAULT = 'DEFAULT'
    """Selects the default accelerator for the given :class:`Engine`"""

    CPU = 'CPU'
    """Run the :class:`Engine` on the CPU"""

    GPU = 'GPU'
    """Run the :class:`Engine` on the GPU."""

    MYRIAD = 'MYRIAD'
    """
    Run the :class:`Engine` on a MYRIAD accelerator (NCS2)
    """

    NVIDIA = 'NVIDIA'
    """
    Run the :class:`Engine` on a NVIDIA gpu accelerator
    """

    NVIDIA_FP16 = 'NVIDIA_FP16'
    """
    Run the :class:`Engine` on a NVIDIA gpu accelerator compressed to
    floating point 16
    """
