

import numpy as np



class EyeCloudFrame(np.ndarray):
    '''
    This class extends `numpy.ndarray` with an additional `sequence_index` attribute.
    '''
    def __new__(cls, frame, sequence_index):
        pass

    def __array_finalize__(self, frame_obj):
        pass

    @property
    def sequence_index(self):
        pass

class EyeCloud:
    """
    Class to be used to with EyeCloud OpenNCC cameras to capture frames and to execute models.

    EyeCloud is currently supported on amd64 (Desktop) and armv7hf (Raspberry Pi 4).

    Containers with EyeCloud support are tagged as follows::

        <repo-id>:eyecloud-<architecture>-<version>

    Typical usage::

        with edgeiq.eyecloud.EyeCloud('alwaysai/mobilenet-ssd-eyecloud') as camera:

            while True:
                frame = camera.get_frame()
                frame_sequence_index = frame.sequence_index

                result = camera.get_model_result(confidence_level=.75)
                if result:
                    model_sequence_index = result.sequence_index

    :type model_id: string
    :param model_id: The ID of the model you want to initialize on the camera.
                     Supported model purposes: Object Detection, Classification, Pose Estimation.
                     Intializing the camera with no model_id or supplying None will still allow you to capture frames.
    """

    __MEDIA_HEAD = 'iII13I'
    __PREDICTION_SUBLIST_LENGTH = 7
    __DEVICE = "EYECLOUD"
    __SUPPORTED_MODEL_FRAMEWORK_TYPES = ["MYRIAD"]

    def __init__(self, model_id=None):
        pass

    @property
    def model_id(self):
        pass

    @property
    def model_purpose(self):
        pass

    def start(self):
        pass

    def stop(self):
        pass

    def get_frame(self):
        pass

    def get_model_result(self, **inference_args):
        pass

    def get_frame_data(self):
        pass

    def process_frame_data(self, frame_data):
        pass

    def get_model_data(self):
        pass

    def __enter__(self):
        pass

    def __exit__(self, type, value, traceback):
        pass

    def __del__(self):
        pass

