from norfair import Tracker, Detection

#########################################################################################
# Monkey-patched classes and functions
#########################################################################################


class DetectionEdgeIQ(Detection):
    def __init__(self, prediction):
        pass

def update_objects_in_place_edgeiq(
    self,
    objects,
    detections
):
    pass

Tracker.update_objects_in_place = update_objects_in_place_edgeiq


class KalmanTracker():
    """
    Associate a bounding box with an object ID based on distances from
    previous detections.
    Works similarly to the centroid tracker. Each
    tracked object is now assigned a Kalman Filter, which is updated
    after each frame, whose purpose is to model and understand the
    motion of the object being tracked. This adds a level of robustness
    to the tracking system, as the future position/velocity of the object
    may be estimated and used when matching objects in frame rather than
    just the object's current position. This additional complexity adds
    computational overhead.

    Typical usage::

        obj_detect = edgeiq.ObjectDetection(
                'alwaysai/res10_300x300_ssd_iter_140000')
        obj_detect.load(engine=edgeiq.Engine.DNN)

        kalman_tracker = edgeiq.KalmanTracker(
                deregister_frames=20,
                max_distance=50,
                distance_metric="euclidean")

        while True:
            <get video frame>
            results = obj_detect.detect_objects(frame)

            objects = centroid_tracker.update(results.predictions)

            # Use the object dictionary to create a new prediction list
            for (object_id, prediction) in objects.items():
                new_label = 'object {}'.format(object_id)
                prediction.label = new_label
                predictions.append(prediction)

            frame = edgeiq.markup_image(frame, predictions)

    :type deregister_frames: integer
    :param deregister_frames: The number of frames before deregistering an
                              object that can no longer be found.
    :type max_distance: integer
    :param max_distance: The maximum distance between two centroids to
                         associate an object.
    """
    def __init__(self,
                 deregister_frames=4,
                 max_distance=40):
        pass

    def update(self, results):
        pass

