from enum import Enum


DEFAULT_DEREGISTER_FRAMES = 30
DEFAULT_MAX_DISTANCE = 50


class TrackingState(Enum):
    DETECT = 'DETECT'
    REDETECT = 'REDETECT'


class TrackablePrediction():
    def __init__(self, prediction):
        pass

class TrackerAlgorithm():
    def __init__(
            self, deregister_frames, max_distance, enter_cb, exit_cb,
            found_handler=None, disappeared_handler=None):
        pass

    def update(self, predictions, **trackable_kwargs):
        pass

class CorrelationTracker():
    """
    Track objects based on a correlation tracking algorithm.

    Typical usage::

        obj_detect = edgeiq.ObjectDetection(
                'alwaysai/res10_300x300_ssd_iter_140000')
        obj_detect.load(engine=edgeiq.Engine.DNN)

        tracker = edgeiq.CorrelationTracker()

        while True:
            <get video frame>
            results = obj_detect.detect_objects(frame)

            objects = tracker.update(results.predictions, frame)

            # Use the object dictionary to create a new prediction list
            for (object_id, prediction) in objects.items():
                new_label = 'object {}'.format(object_id)
                prediction.label = new_label
                predictions.append(prediction)

            frame = edgeiq.markup_image(frame, predictions)

    :type max_objects: integer
    :param max_objects: The maximum number of objects to track.
    :type deregister_frames: integer
    :param deregister_frames: The number of frames before deregistering an
                              object that can no longer be found.
    :type max_distance: integer
    :param max_distance: The maximum distance between two centroids to
                         associate an object.
    :type enter_cb: function that takes the object ID and
                    :class:`~edgeiq.object_detection.ObjectDetectionPrediction`
                    as arguments.
    :param enter_cb: A callback function to be called each time a new object is
                     detected.
    :type exit_cb: function that takes the object ID and
                    :class:`~edgeiq.object_detection.ObjectDetectionPrediction`
                    as arguments.
    :param exit_cb: A callback function to be called each time an existing object is
                    removed from the tracking list. This event occurs `deregister_frames`
                    after the object is last detected.
    """
    def __init__(
            self, max_objects=None, deregister_frames=DEFAULT_DEREGISTER_FRAMES,
            max_distance=DEFAULT_MAX_DISTANCE, enter_cb=None, exit_cb=None):
        pass

    def update(self, predictions, image):
        pass

class CentroidTracker():
    """
    Associate a bounding box with an object ID based on distances from
    previous detections.

    Typical usage::

        obj_detect = edgeiq.ObjectDetection(
                'alwaysai/res10_300x300_ssd_iter_140000')
        obj_detect.load(engine=edgeiq.Engine.DNN)

        centroid_tracker = edgeiq.CentroidTracker(
                deregister_frames=20, max_distance=50)

        while True:
            <get video frame>
            results = obj_detect.detect_objects(frame)

            objects = centroid_tracker.update(results.predictions)

            # Use the object dictionary to create a new prediction list
            for (object_id, prediction) in objects.items():
                new_label = 'object {}'.format(object_id)
                prediction.label = new_label
                predictions.append(prediction)

            frame = edgeiq.markup_image(frame, predictions)

    :type deregister_frames: integer
    :param deregister_frames: The number of frames before deregistering an
                              object that can no longer be found.
    :type max_distance: integer
    :param max_distance: The maximum distance between two centroids to
                         associate an object.
    :type enter_cb: function that takes the object ID and
                    :class:`~edgeiq.object_detection.ObjectDetectionPrediction`
                    as arguments.
    :param enter_cb: A callback function to be called each time a new object is
                     detected.
    :type exit_cb: function that takes the object ID and
                    :class:`~edgeiq.object_detection.ObjectDetectionPrediction`
                    as arguments.
    :param exit_cb: A callback function to be called each time an existing object is
                    removed from the tracking list. This event occurs `deregister_frames`
                    after the object is last detected.
    """
    def __init__(
            self, deregister_frames=DEFAULT_DEREGISTER_FRAMES,
            max_distance=DEFAULT_MAX_DISTANCE, enter_cb=None, exit_cb=None):
        pass

    def update(self, predictions):
        pass

def match_detections_with_centroid(id_objects, new_predictions, max_distance):
    pass

