import platform
import ctypes
import os





NATIVE_LIBRARY_LOADED = False
if platform.system() == 'Linux':
    if platform.machine() in ['x86_64', 'amd64']:
        lib_file = 'libhuman_pose.so.amd64'
    elif platform.machine() in ['armv7l', 'armv7hf', 'arm32']:
        lib_file = 'libhuman_pose.so.armv7hf'
    elif platform.machine() in ['aarch64', 'arm64']:
        lib_file = 'libhuman_pose.so.aarch64'

    try:
        libhuman_pose = ctypes.cdll.LoadLibrary(
            os.path.join(os.path.dirname(__file__), 'ext_libs', 'human_pose',
                         lib_file))

        libhuman_pose.postprocess.argtypes = (
            ctypes.POINTER(ctypes.c_float),  # HeatMaps
            ctypes.c_int,  # HeatMapOffSet
            ctypes.c_int,  # NHeatMaps
            ctypes.POINTER(ctypes.c_float),  # PartialAffinityFields (PAF)
            ctypes.c_int,  # PAFOffset
            ctypes.c_int,  # NPAFS
            ctypes.c_int,  # FeatureMapWidth
            ctypes.c_int,  # FeatureMapHeight
            ctypes.c_int,  # ImageWidth
            ctypes.c_int,  # imageHeight
            ctypes.POINTER(ctypes.c_int))  # array width
        libhuman_pose.postprocess.restype = ctypes.POINTER(ctypes.c_void_p)

        libhuman_pose.get_key_points_from_pose.argtypes = (ctypes.c_void_p,
                                                           ctypes.c_int)

        libhuman_pose.get_key_point_array_size.argtypes = (ctypes.c_void_p,
                                                           ctypes.c_int)
        libhuman_pose.get_key_point_array_size.restype = ctypes.c_ulong

        libhuman_pose.get_score_from_pose.argtypes = (ctypes.c_void_p,
                                                      ctypes.c_int)
        libhuman_pose.get_score_from_pose.restype = ctypes.c_float

        libhuman_pose.del_temp_poses.argtypes = (ctypes.c_void_p, )

        NATIVE_LIBRARY_LOADED = True

    except OSError as exception:
        if 'libopencv_imgproc.so' in str(
                exception):
            _logger.debug('catching opencv .so error to avoid failures in test context')
        else:
            raise

if not NATIVE_LIBRARY_LOADED:
    _logger.info(
        'Human pose native library not available for this platform, '
        'performance may suffer.')
"""Used for grouping keypoints"""
BODY_PARTS_KPT_IDS = [[1, 2], [1, 5], [2, 3], [3, 4], [5, 6], [6, 7], [1, 8],
                      [8, 9], [9, 10], [1, 11], [11, 12], [12, 13], [1, 0],
                      [0, 14], [14, 16], [0, 15], [15, 17], [2, 16], [5, 17]]
BODY_PARTS_PAF_IDS = ([12, 13], [20, 21], [14, 15], [16, 17], [22,
                                                               23], [24, 25],
                      [0, 1], [2, 3], [4, 5], [6, 7], [8, 9], [10,
                                                               11], [28, 29],
                      [30, 31], [34, 35], [32, 33], [36, 37], [18,
                                                               19], [26, 27])


def get_poses(result, image):
    pass

