



class Streamer:
    """
    Host a video and data streaming server on the device.

    `Streamer` can be instantiated as a context manager::

        with edgeiq.Streamer() as streamer:
            ...

    To use `Streamer` directly, use the :func:`~edgeiq.streamer.Streamer.setup()`
    and :func:`~edgeiq.streamer.Streamer.close()` functions::

        streamer = edgeiq.Streamer().setup()
        ...
        streamer.close()

    For a video stream, the default parameters are all you need. The `Streamer`
    web page has a "stop" button which you can check with the
    :func:`~edgeiq.streamer.Streamer.check_exit()` function::

        with edgeiq.Streamer() as streamer:
            while True:
                <get video frame>
                streamer.send_data(frame, 'This will be printed on the Streamer')

                if streamer.check_exit():
                    break

    For a series of images (slideshow mode), set the queue depth to the total
    number of images to be displayed, and set the inter-message time to the
    time in seconds you'd like each image to be displayed. Note that the
    inter-message time doesn't take into account any delay in sending the
    message to the `Streamer`. You'll also need to call the
    :func:`~edgeiq.streamer.Streamer.wait()` function to make sure the app
    keeps running until all images have been sent to the web page. The "stop"
    button also works in this mode, but doesn't need an explicit check since it's
    checked in the :func:`~edgeiq.streamer.Streamer.wait()` function.
    ::

        with edgeiq.Streamer(
                queue_depth=len(image_list), inter_msg_time=4) as streamer:
            for image in image_list:
                streamer.send_data(image, 'This image will be displayed for 4 seconds')

            streamer.wait()

    :type queue_depth: integer
    :param queue_depth: The depth of the data queue used for communication
                        between the application process and server process.
    :type inter_msg_time: float
    :param inter_msg_time: The time in seconds between message sends to
                           attached clients.
    :type drop_frames: boolean
    :param drop_frames: Indicates whether :func:`~send_data()` should block
                        when queue is full or drop frames.
    """
    def __init__(
            self, queue_depth=2, inter_msg_time=0, drop_frames=True, **kwargs):
        pass

    def setup(self):
        pass

    def send_data(self, image=None, text=None):
        pass

    def wait(self):
        pass

    def check_exit(self):
        pass

    def close(self):
        pass

    def __enter__(self):
        pass

    def __exit__(self, type, value, traceback):
        pass

    def __del__(self):
        pass

@_socketio.on('streamer-user')
def handle_message(message):
    pass

@_app.route('/stop', methods=['POST'])
def stop():
    pass

